@@ -7,7 +7,7 @@ COPYRIGHT
    © 2020 Steffen Brinkmann <s-b@mailbox.org>
 """
 
-__version__ = "0.1.6"
+__version__ = "0.1.7"
 
 from .log_fmt import (  # noqa: F401
     config_logger,
@@ -16,4 +16,4 @@ from .log_fmt import (  # noqa: F401
     file_handler,
 )
 
-from .log_decorator import Log  # noqa: F401
+from .log_decorator import log  # noqa: F401
